// import { Component } from '@angular/core';
// import * as am4core from "@amcharts/amcharts4/core";
// import * as am4charts from "@amcharts/amcharts4/charts";
// import am4themes_animated from "@amcharts/amcharts4/themes/animated";

import {
  Component,
  OnInit,
  OnDestroy,
  NgZone,
  ViewChild,
  ElementRef,
} from '@angular/core';
import * as am4core from '@amcharts/amcharts4/core';
import * as am4charts from '@amcharts/amcharts4/charts';
import am4themes_animated from '@amcharts/amcharts4/themes/animated';

interface ChartData {
  category: string;
  value: number;
  subData?: ChartData[]; // Optional because not all items may have subdata
}

@Component({
  selector: 'app-root',
  templateUrl: './amcharts-drilldown.component.html',
  styleUrl: './amcharts-drilldown.component.css',
})
export class AmchartsDrilldownComponent implements OnInit, OnDestroy {
  private chart!: am4charts.XYChart;

  constructor(private zone: NgZone) {}

  ngOnInit(): void {}

  ngAfterViewInit() {
    this.zone.runOutsideAngular(() => {
      am4core.useTheme(am4themes_animated);

      let chart = am4core.create('chartdiv', am4charts.XYChart);
      chart.hiddenState.properties.opacity = 0; // this creates initial fade-in

      chart.data = [
        {
          category: 'Fruits',
          value: 300,
          subData: [
            { category: 'Apples', value: 120 },
            { category: 'Oranges', value: 80 },
            { category: 'Bananas', value: 100 },
          ],
        },
        {
          category: 'Vegetables',
          value: 200,
          subData: [
            { category: 'Tomatoes', value: 90 },
            { category: 'Peppers', value: 60 },
            { category: 'Carrots', value: 50 },
          ],
        },
      ];

      let categoryAxis = chart.xAxes.push(new am4charts.CategoryAxis());
      categoryAxis.dataFields.category = 'category';
      categoryAxis.renderer.grid.template.location = 0;

      let valueAxis = chart.yAxes.push(new am4charts.ValueAxis());

      let series = chart.series.push(new am4charts.ColumnSeries());
      series.dataFields.valueY = 'value';
      series.dataFields.categoryX = 'category';
      series.columns.template.tooltipText = '{categoryX}: [bold]{valueY}[/]';
      series.columns.template.fillOpacity = 0.8;

      let columnTemplate = series.columns.template;
      columnTemplate.strokeWidth = 2;
      columnTemplate.strokeOpacity = 1;

      series.columns.template.events.on('hit', (ev) => {
        // let data = ev.target.dataItem.dataContext['subData'];
        // let data = ev.target.dataItem?.dataContext as any;
        // if (data) {
        //   chart.data = data;
        // }
        let data = ev.target.dataItem?.dataContext as ChartData;
        if (data && data.subData) {
          chart.data = data.subData;
        }
      });

      this.chart = chart;
    });
  }

  ngOnDestroy() {
    this.zone.runOutsideAngular(() => {
      if (this.chart) {
        this.chart.dispose();
      }
    });
  }
}

// @Component({
//   selector: 'app-amcharts-drilldown',
//   templateUrl: './amcharts-drilldown.component.html',
//   styleUrl: './amcharts-drilldown.component.css'
// })
// export class AmchartsDrilldownComponent {

// }
